# AUTOGENERATED! DO NOT EDIT! File to edit: ../../pts/api/test123/folder/subfolder/notebook7.pct.py.

# %% auto 0
__all__ = ['foobar']

# %% ../../pts/api/test123/folder/subfolder/notebook7.pct.py 3
def foobar():
    pass



# AUTOGENERATED! DO NOT EDIT! File to edit: ../../pts/api/test123/notebook2.pct.py.

# %% auto 0
__all__ = ['bar']

# %% ../../pts/api/test123/notebook2.pct.py 3
from my_module.notebook1 import foo

# %% ../../pts/api/test123/notebook2.pct.py 4
def bar():
    foo()
    print("world")



# AUTOGENERATED! DO NOT EDIT! File to edit: ../../../../../../../../Users/lukastk/dev-proj/nblite/pts/api/test123/func_notebook.pct.py.

# %% top_export
def a_decorator(func):
    def wrapper(*args, **kwargs):
        print("Function is being called")
        result = func(*args, **kwargs)
        print("Function has been called")
        return result
    return wrapper

@a_decorator
def nb_func(): 
    # %% ../../../../../../../../Users/lukastk/dev-proj/nblite/pts/api/test123/func_notebook.pct.py 4
    print("This will be in the body of the function.")
    my_val = "Hello, world!"
    return my_val


# AUTOGENERATED! DO NOT EDIT! File to edit: ../../pts/api/test123/folder/notebook4.pct.py.

# %% auto 0
__all__ = ['foobar']

# %% ../../pts/api/test123/folder/notebook4.pct.py 3
from my_module.notebook1 import foo
from my_module.notebook2 import bar

# %% ../../pts/api/test123/folder/notebook4.pct.py 4
def foobar():
    foo()
    bar()
